@@ -23,7 +23,14 @@
 #include <QApplication>
 #include <QPropertyAnimation>
 #include <QtCore/QStringBuilder>
+#include <QtDeclarative/QDeclarativeView>
+#include <QtDeclarative/QDeclarativeContext>
+#include <QtDeclarative/QDeclarativeComponent>
+#include <QtDeclarative/QDeclarativeError>
 #include <QtGui/QHBoxLayout>
+#include <QtGui/QGraphicsDropShadowEffect>
+#include <QtGui/QGraphicsBlurEffect>
+#include <QtGui/QGraphicsObject>
 #include <QtGui/QLabel>
 #include <QtGui/QProgressBar>
 #include <QtGui/QPushButton>
@@ -39,6 +46,7 @@
 #include <KPixmapSequence>
 #include <kpixmapsequenceoverlaypainter.h>
 #include <KService>
+#include <KStandardDirs>
 #include <KStandardGuiItem>
 #include <KTemporaryFile>
 #include <KToolInvocation>
@@ -63,13 +71,13 @@
 #include "AddonsWidget.h"
 #include "Application.h"
 #include "ClickableLabel.h"
-#include "effects/GraphicsOpacityDropShadowEffect.h"
-#include "ScreenShotViewer.h"
+#include "ScreenShotOverlay.h"
 #include "ReviewsBackend/Rating.h"
 #include "ReviewsBackend/Review.h"
 #include "ReviewsBackend/ReviewsWidget.h"
 #include "ReviewsBackend/ReviewsBackend.h"
 #include "../../libmuon/MuonStrings.h"
+#include "../../libmuon/mobile/src/mousecursor.h"
 
 #define BLUR_RADIUS 15
 
@@ -77,8 +85,10 @@ ApplicationDetailsWidget::ApplicationDetailsWidget(QWidget *parent, ApplicationB
     : QScrollArea(parent)
     , m_appBackend(backend)
     , m_screenshotFile(0)
-    , m_screenshotDialog(0)
 {
+    qmlRegisterType<QGraphicsDropShadowEffect>("Effects",1,0,"DropShadow");
+    qmlRegisterType<MouseCursor>("MuonMobile", 1, 0, "MouseCursor");
+
     setWidgetResizable(true);
     viewport()->setAutoFillBackground(false);
 
@@ -190,20 +200,24 @@ ApplicationDetailsWidget::ApplicationDetailsWidget(QWidget *parent, ApplicationB
     m_websiteLabel->setAlignment(Qt::AlignLeft);
     m_websiteLabel->setOpenExternalLinks(true);
 
-    m_screenshotLabel = new ClickableLabel(body);
-    m_screenshotLabel->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
-    m_screenshotLabel->setMinimumSize(170, 130);
+    m_screenshotView = new QDeclarativeView(this);
+    m_screenshotView->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+    m_screenshotView->setMinimumSize(170, 130);
+    m_screenshotView->rootContext()->setContextProperty("view", m_screenshotView);
+    m_screenshotView->setSource(KStandardDirs::locate("data", QLatin1String("libmuon/ThumbnailView.qml")));
+    QObject *item = m_screenshotView->rootObject();
+    connect(item, SIGNAL(thumbnailClicked()), this, SLOT(screenshotLabelClicked()));
 
-    m_throbberWidget = new KPixmapSequenceOverlayPainter(m_screenshotLabel);
+    m_throbberWidget = new KPixmapSequenceOverlayPainter(m_screenshotView->viewport());
     m_throbberWidget->setSequence(KPixmapSequence("process-working", 22));
     m_throbberWidget->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
-    m_throbberWidget->setWidget(m_screenshotLabel);
+    m_throbberWidget->setWidget(m_screenshotView->viewport());
     m_throbberWidget->start();
-
-    connect(m_screenshotLabel, SIGNAL(clicked()), this, SLOT(screenshotLabelClicked()));
+    connect(item, SIGNAL(thumbnailLoaded()), m_throbberWidget, SLOT(stop()));
 
     bodyLayout->addWidget(bodyLeft);
-    bodyLayout->addWidget(m_screenshotLabel);
+    bodyLayout->addWidget(m_screenshotView);
+    m_screenshotView->show();
 
     m_addonsWidget = new AddonsWidget(widget, m_appBackend);
     connect(m_addonsWidget, SIGNAL(applyButtonClicked(QHash<QApt::Package *, QApt::Package::State>)),
@@ -249,6 +263,20 @@ ApplicationDetailsWidget::ApplicationDetailsWidget(QWidget *parent, ApplicationB
     QWidget *verticalSpacer = new QWidget(this);
     verticalSpacer->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding);
 
+    // Blur effect for later
+    m_blurEffect = new QGraphicsBlurEffect(widget);
+    m_blurEffect->setBlurHints(QGraphicsBlurEffect::PerformanceHint);
+    m_blurEffect->setBlurRadius(0);
+    widget->setGraphicsEffect(m_blurEffect);
+
+    m_fadeBlur = new QPropertyAnimation(m_blurEffect, "blurRadius", this);
+    m_fadeBlur->setDuration(200);
+    m_fadeBlur->setStartValue(qreal(0));
+    m_fadeBlur->setEndValue(qreal(5));
+
+    // Workarounds for QScrollAreas not repainting whilst under the effects of a QGraphicsEffect
+    connect(m_fadeBlur, SIGNAL(finished()), m_addonsWidget, SLOT(repaintViewport()));
+    connect(m_fadeBlur, SIGNAL(finished()), m_screenshotView->viewport(), SLOT(repaint()));
 
     layout->addWidget(headerWidget);
     layout->addWidget(m_menuPathWidget);
@@ -339,9 +367,11 @@ void ApplicationDetailsWidget::setApplication(Application *app)
     }
 
     if (!app->package()->isInstalled()) {
-         m_version->setText(app->package()->availableVersion());
+         m_version->setText(app->package()->latin1Name() % ' ' %
+                            app->package()->availableVersion());
     } else {
-         m_version->setText(app->package()->installedVersion());
+         m_version->setText(app->package()->latin1Name() % ' ' %
+                            app->package()->installedVersion());
     }
 
     if (app->package()->component() == "main" ||
@@ -555,15 +585,8 @@ void ApplicationDetailsWidget::populateZeitgeistInfo()
 #endif // HAVE_QZEITGEIST
 }
 
-void ApplicationDetailsWidget::fadeInScreenshot()
-{
-    m_fadeScreenshot->setDirection(QAbstractAnimation::Forward);
-    m_fadeScreenshot->start();
-}
-
 void ApplicationDetailsWidget::fetchScreenshot(QApt::ScreenshotType screenshotType)
 {
-    m_screenshotLabel->setCursor(Qt::BusyCursor);
     if (m_screenshotFile) {
         m_screenshotFile->deleteLater();
         m_screenshotFile = 0;
@@ -573,90 +596,71 @@ void ApplicationDetailsWidget::fetchScreenshot(QApt::ScreenshotType screenshotTy
     m_screenshotFile->setSuffix(".png");
     m_screenshotFile->open();
 
-    KIO::FileCopyJob *getJob = KIO::file_copy(m_app->screenshotUrl(screenshotType),
-                               m_screenshotFile->fileName(), -1, KIO::Overwrite | KIO::HideProgressInfo);
-
     switch (screenshotType) {
-    case QApt::Thumbnail:
-        connect(getJob, SIGNAL(result(KJob *)),
-            this, SLOT(thumbnailFetched(KJob *)));
+    case QApt::Thumbnail: {
+        QObject *object = m_screenshotView->rootObject();
+        if (object) {
+            object->setProperty("source", m_app->screenshotUrl(QApt::Thumbnail).pathOrUrl());
+        }
         break;
-    case QApt::Screenshot:
+    }
+    case QApt::Screenshot: {
+        KIO::FileCopyJob *getJob = KIO::file_copy(m_app->screenshotUrl(screenshotType),
+                               m_screenshotFile->fileName(), -1, KIO::Overwrite | KIO::HideProgressInfo);
         connect(getJob, SIGNAL(result(KJob *)),
             this, SLOT(screenshotFetched(KJob *)));
         break;
+    }
     case QApt::UnknownType:
     default:
         break;
     }
 }
 
-void ApplicationDetailsWidget::thumbnailFetched(KJob *job)
-{
-    m_throbberWidget->stop();
-    if (job->error()) {
-        m_screenshotLabel->hide();
-        return;
-    }
-
-    GraphicsOpacityDropShadowEffect *shadow = new GraphicsOpacityDropShadowEffect(m_screenshotLabel);
-    shadow->setBlurRadius(BLUR_RADIUS);
-    shadow->setOpacity(0);
-    shadow->setOffset(2);
-    shadow->setColor(QApplication::palette().dark().color());
-    m_screenshotLabel->setGraphicsEffect(shadow);
-
-    m_fadeScreenshot = new QPropertyAnimation(shadow, "opacity", this);
-    m_fadeScreenshot->setDuration(500);
-    m_fadeScreenshot->setStartValue(qreal(0));
-    m_fadeScreenshot->setEndValue(qreal(1));
-
-    m_screenshotLabel->setPixmap(QPixmap(m_screenshotFile->fileName()).scaled(160,120, Qt::KeepAspectRatio, Qt::SmoothTransformation));
-    m_screenshotLabel->setCursor(Qt::PointingHandCursor);
-    fadeInScreenshot();
-}
-
 void ApplicationDetailsWidget::screenshotFetched(KJob *job)
 {
-    m_screenshotLabel->unsetCursor();
     if (job->error()) {
         return;
     }
 
-    m_screenshotDialog = new ScreenShotViewer(m_screenshotFile->fileName());
-    connect(m_screenshotDialog, SIGNAL(destroyed(QObject *)),
-            this, SLOT(onScreenshotDialogClosed()));
-    connect(m_screenshotDialog, SIGNAL(finished(int)),
-            this, SLOT(onScreenshotDialogClosed()));
-    m_screenshotDialog->setWindowTitle(m_app->name());
-    m_screenshotDialog->show();
+    m_fadeBlur->setDirection(QAbstractAnimation::Forward);
+    m_fadeBlur->start();
+
+    ScreenShotOverlay *overlay = new ScreenShotOverlay(m_screenshotFile->fileName(), viewport(), this);
+    connect(overlay, SIGNAL(destroyed(QObject*)), this, SLOT(overlayClosed()));
+}
+
+void ApplicationDetailsWidget::overlayClosed()
+{
+    QObject *item = m_screenshotView->rootObject();
+    connect(item, SIGNAL(thumbnailClicked()), this, SLOT(screenshotLabelClicked()));
+
+    m_fadeBlur->setDirection(QAbstractAnimation::Backward);
+    m_fadeBlur->start();
+
+    unsetCursor();
 }
 
 void ApplicationDetailsWidget::screenshotLabelClicked()
 {
+    QObject *item = m_screenshotView->rootObject();
+    disconnect(item, SIGNAL(thumbnailClicked()), this, SLOT(screenshotLabelClicked()));
     fetchScreenshot(QApt::Screenshot);
 }
 
-void ApplicationDetailsWidget::onScreenshotDialogClosed()
-{
-    m_screenshotLabel->setCursor(Qt::PointingHandCursor);
-    m_screenshotDialog->deleteLater();
-    m_screenshotDialog = 0;
-}
-
 void ApplicationDetailsWidget::actionButtonClicked()
 {
+    m_actionButton->hide();
+    m_progressBar->show();
+    m_progressBar->setValue(0);
+    m_progressBar->setFormat(i18nc("@info:status Progress text when waiting", "Waiting"));
+
     // TODO: update packages
     if (m_app->package()->isInstalled()) {
         emit removeButtonClicked(m_app);
     } else {
         emit installButtonClicked(m_app);
     }
-
-    m_actionButton->hide();
-    m_progressBar->show();
-    m_progressBar->setValue(0);
-    m_progressBar->setFormat(i18nc("@info:status Progress text when waiting", "Waiting"));
 }
 
 void ApplicationDetailsWidget::cancelButtonClicked()
