@@ -158,6 +158,7 @@ void MainWindow::workerEvent(QApt::WorkerEvent event)
         if (m_backend) {
             m_progressWidget->animatedHide();
             m_updaterWidget->setEnabled(true);
+            m_updaterWidget->setCurrentIndex(0);
             reload();
             setActionsEnabled();
         }
@@ -238,6 +239,7 @@ void MainWindow::setActionsEnabled(bool enabled)
     m_undoAction->setEnabled(!m_backend->isUndoStackEmpty());
     m_redoAction->setEnabled(!m_backend->isRedoStackEmpty());
     m_revertAction->setEnabled(!m_backend->isUndoStackEmpty());
+    m_updaterWidget->setEnabled(true);
 }
 
 void MainWindow::checkForUpdates()
@@ -310,6 +312,12 @@ void MainWindow::closeHistoryDialog()
 void MainWindow::checkPlugState()
 {
     const QList<Solid::Device> acAdapters = Solid::Device::listFromType(Solid::DeviceInterface::AcAdapter);
+
+    if (acAdapters.isEmpty()) {
+        updatePlugState(true);
+        return;
+    }
+    
     bool isPlugged = false;
 
     foreach(Solid::Device device_ac, acAdapters) {
